configlet create


Wenn du einen neuen Ansatz, Artikel oder eine neue Übung hinzufügst, musst du Dateien mit ganz bestimmten Namen erstellen. Außerdem musst du Konfigurationsdateien hinzufügen oder aktualisieren. Mit dem create-Befehl erledigt configlet das alles für dich.

Verwendung

Mit dem create-Befehl kannst du die Dateien erstellen, die für einen neuen Ansatz, Artikel oder eine neue Übung nötig sind, und außerdem alle Konfigurationsdateien anpassen.

configlet [global-options] create [command-options]

Options for create:
      --approach <slug>           The slug of the approach
      --article <slug>            The slug of the article
      --practice-exercise <slug>  The slug of the practice exercise
      --concept-exercise <slug>   The slug of the concept exercise
  -e, --exercise <slug>           Only operate on this exercise
  -o, --offline                   Do not update the cached 'problem-specifications' data

Practice-Übung erstellen

Die Dokumentation zum Hinzufügen einer Practice-Übung enthält eine ausführliche Anleitung, wie du eine Practice-Übung hinzufügst.

Konzeptübung erstellen

Um eine Konzeptübung zu erstellen, musst du ihren Slug angeben:

configlet create --concept-exercise bird-watcher

Damit werden die erforderlichen Dateien für die Konzeptübung erstellt, wie in der Dokumentation zu den Konzeptübungen beschrieben.

Das ist natürlich nur der erste Schritt, um eine Übung zu erstellen. Danach musst du noch:

  • Tests zur Testdatei hinzufügen
  • Eine Beispielimplementierung hinzufügen
  • Den Inhalt der Stub-Datei festlegen
  • Die Einführung in .docs/introduction.md schreiben
  • Die Anleitung in .docs/instructions.md schreiben
  • In der Datei .meta/config.json der Übung:
    • Den GitHub-Benutzernamen der Autorinnen und Autoren der Übung im Schlüssel authors hinzufügen
  • In der Datei config.json des Tracks:
    • Die Schwierigkeit der Übung prüfen/aktualisieren
    • Konzepte im Schlüssel concepts hinzufügen
    • Konzepte im Schlüssel prerequisites hinzufügen

Ansatz erstellen

Um die Dateien für einen Ansatz zu erstellen, musst du den Slug des Ansatzes und der zugehörigen Übung angeben:

configlet create --approach recursion --exercise collatz-conjecture

Damit werden die erforderlichen Dateien für den Ansatz erstellt, wie in der Dokumentation zu den Ansätzen beschrieben.

Artikel erstellen

Um die Dateien für einen Artikel zu erstellen, musst du den Slug des Artikels und der zugehörigen Übung angeben:

configlet create --article performance --exercise collatz-conjecture

Damit werden die erforderlichen Dateien für den Artikel erstellt, wie in der Dokumentation zu den Artikeln beschrieben.